@@ -18,6 +18,7 @@ from .util import (
     )
 from .errors import (
     ConnectionClosedError,
+    ConnectionForcedCloseError,
     RedisError,
     ProtocolError,
     ReplyError,
@@ -42,7 +43,7 @@ _PUBSUB_COMMANDS = (
 
 @asyncio.coroutine
 def create_connection(address, *, db=None, password=None, ssl=None,
-                      encoding=None, loop=None):
+                      encoding=None, loop=None, timeout=None):
     """Creates redis connection.
 
     Opens connection to Redis server specified by address argument.
@@ -54,6 +55,10 @@ def create_connection(address, *, db=None, password=None, ssl=None,
     SSL argument is passed through to asyncio.create_connection.
     By default SSL/TLS is not used.
 
+    By default any timeout is applied at the connection stage, however
+    you can set a limitted time used trying to open a connection via
+    the `timeout` Kw.
+
     Encoding argument can be used to decode byte-replies to strings.
     By default no decoding is done.
 
@@ -63,11 +68,14 @@ def create_connection(address, *, db=None, password=None, ssl=None,
     """
     assert isinstance(address, (tuple, list, str)), "tuple or str expected"
 
+    if timeout is not None and timeout <= 0:
+        raise ValueError("Timeout has to be None or a number greater than 0")
+
     if isinstance(address, (list, tuple)):
         host, port = address
         logger.debug("Creating tcp connection to %r", address)
-        reader, writer = yield from asyncio.open_connection(
-            host, port, ssl=ssl, loop=loop)
+        reader, writer = yield from asyncio.wait_for(asyncio.open_connection(
+            host, port, ssl=ssl, loop=loop), timeout, loop=loop)
         sock = writer.transport.get_extra_info('socket')
         if sock is not None:
             sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
@@ -75,8 +83,9 @@ def create_connection(address, *, db=None, password=None, ssl=None,
         address = tuple(address[:2])
     else:
         logger.debug("Creating unix connection to %r", address)
-        reader, writer = yield from asyncio.open_unix_connection(
-            address, ssl=ssl, loop=loop)
+        reader, writer = yield from asyncio.wait_for(
+            asyncio.open_unix_connection(address, ssl=ssl, loop=loop),
+            timeout, loop=loop)
         sock = writer.transport.get_extra_info('socket')
         if sock is not None:
             address = sock.getpeername()
@@ -127,15 +136,19 @@ class RedisConnection:
     @asyncio.coroutine
     def _read_data(self):
         """Response reader task."""
+        last_error = ConnectionClosedError(
+            "Connection has been closed by server")
         while not self._reader.at_eof():
             try:
                 data = yield from self._reader.read(MAX_CHUNK_SIZE)
             except asyncio.CancelledError:
+                # NOTE: reader can get cancelled from `close()` method only.
+                last_error = RuntimeError('this is unexpected')
                 break
             except Exception as exc:
-                # XXX: for QUIT command connection error can be received
+                # NOTE: for QUIT command connection error can be received
                 #       before response
-                logger.error("Exception on data read %r", exc, exc_info=True)
+                last_error = exc
                 break
             self._parser.feed(data)
             while True:
@@ -157,7 +170,7 @@ class RedisConnection:
                     else:
                         self._process_data(obj)
         self._closing = True
-        self._loop.call_soon(self._do_close, None)
+        self._loop.call_soon(self._do_close, last_error)
 
     def _process_data(self, obj):
         """Processes command results."""
@@ -284,7 +297,7 @@ class RedisConnection:
 
     def close(self):
         """Close connection."""
-        self._do_close(None)
+        self._do_close(ConnectionForcedCloseError())
 
     def _do_close(self, exc):
         if self._closed:
@@ -300,9 +313,9 @@ class RedisConnection:
             waiter, *spam = self._waiters.popleft()
             logger.debug("Cancelling waiter %r", (waiter, spam))
             if exc is None:
-                waiter.cancel()
+                _set_exception(waiter, ConnectionForcedCloseError())
             else:
-                waiter.set_exception(exc)
+                _set_exception(waiter, exc)
         while self._pubsub_channels:
             _, ch = self._pubsub_channels.popitem()
             logger.debug("Closing pubsub channel %r", ch)
