@@ -7,6 +7,7 @@ from .commands import create_redis, Redis
 from .log import logger
 from .util import async_task, _NOTSET
 from .errors import PoolClosedError
+from .locks import Lock
 
 
 PY_35 = sys.version_info >= (3, 5)
@@ -14,7 +15,9 @@ PY_35 = sys.version_info >= (3, 5)
 
 @asyncio.coroutine
 def create_pool(address, *, db=0, password=None, ssl=None, encoding=None,
-                minsize=1, maxsize=10, commands_factory=_NOTSET, loop=None):
+                minsize=1, maxsize=10, commands_factory=_NOTSET,
+                loop=None, create_connection_timeout=None):
+    # FIXME: rewrite docstring
     """Creates Redis Pool.
 
     By default it creates pool of Redis instances, but it is
@@ -37,6 +40,7 @@ def create_pool(address, *, db=0, password=None, ssl=None, encoding=None,
     pool = RedisPool(address, db, password, encoding,
                      minsize=minsize, maxsize=maxsize,
                      commands_factory=commands_factory,
+                     create_connection_timeout=create_connection_timeout,
                      ssl=ssl, loop=loop)
     try:
         yield from pool._fill_free(override_min=False)
@@ -53,7 +57,8 @@ class RedisPool:
     """
 
     def __init__(self, address, db=0, password=None, encoding=None,
-                 *, minsize, maxsize, commands_factory, ssl=None, loop=None):
+                 *, minsize, maxsize, commands_factory, ssl=None,
+                 create_connection_timeout=None, loop=None):
         assert isinstance(minsize, int) and minsize >= 0, (
             "minsize must be int >= 0", minsize, type(minsize))
         assert maxsize is not None, "Arbitrary pool size is disallowed."
@@ -70,13 +75,14 @@ class RedisPool:
         self._encoding = encoding
         self._minsize = minsize
         self._factory = commands_factory
+        self._create_connection_timeout = create_connection_timeout
         self._loop = loop
         self._pool = collections.deque(maxlen=maxsize)
         self._used = set()
         self._acquiring = 0
-        self._cond = asyncio.Condition(loop=loop)
+        self._cond = asyncio.Condition(lock=Lock(loop=loop), loop=loop)
         self._close_state = asyncio.Event(loop=loop)
-        self._close_waiter = async_task(self._do_close(), loop=loop)
+        self._close_waiter = None
 
     @property
     def minsize(self):
@@ -132,6 +138,7 @@ class RedisPool:
         """Close all free and in-progress connections and mark pool as closed.
         """
         if not self._close_state.is_set():
+            self._close_waiter = async_task(self._do_close(), loop=self._loop)
             self._close_state.set()
 
     @property
@@ -142,6 +149,8 @@ class RedisPool:
     @asyncio.coroutine
     def wait_closed(self):
         """Wait until pool gets closed."""
+        yield from self._close_state.wait()
+        assert self._close_waiter is not None
         yield from asyncio.shield(self._close_waiter, loop=self._loop)
 
     @property
@@ -258,6 +267,7 @@ class RedisPool:
                             ssl=self._ssl,
                             encoding=self._encoding,
                             commands_factory=self._factory,
+                            timeout=self._create_connection_timeout,
                             loop=self._loop)
 
     @asyncio.coroutine
