@@ -1,6 +1,8 @@
 import asyncio
 import pytest
 
+from unittest.mock import patch
+
 from aioredis import (
     RedisPool,
     ReplyError,
@@ -15,6 +17,7 @@ def _assert_defaults(pool):
     assert pool.maxsize == 10
     assert pool.size == 1
     assert pool.freesize == 1
+    assert pool._close_waiter is None
 
 
 def test_connect(pool):
@@ -57,6 +60,18 @@ def test_maxsize(maxsize, create_pool, loop, server):
             minsize=2, maxsize=maxsize, loop=loop)
 
 
+@pytest.mark.run_loop
+def test_create_connection_timeout(create_pool, loop, server):
+    with patch('asyncio.open_connection') as\
+            open_conn_mock:
+        open_conn_mock.side_effect = lambda *a, **kw: asyncio.sleep(0.2,
+                                                                    loop=loop)
+        with pytest.raises(asyncio.TimeoutError):
+            yield from create_pool(
+                server.tcp_address, loop=loop,
+                create_connection_timeout=0.1)
+
+
 def test_no_yield_from(pool):
     with pytest.raises(RuntimeError):
         with pool:
